/*
 * Copyright (C) 2021 Anton Romanov - All Rights Reserved
 * You may use, distribute and modify this code, please write to: romanov73@gmail.com.
 */

package ru.ulstu.extractor.model;

import org.hibernate.annotations.Fetch;
import org.hibernate.annotations.FetchMode;

import javax.persistence.CascadeType;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.JoinColumn;
import javax.persistence.OneToMany;
import javax.persistence.Transient;
import java.util.ArrayList;
import java.util.List;

@Entity
public class FileChange extends BaseEntity {
    private String file;
    @Transient
    private boolean removed;
    @Transient
    private boolean added;

    private Boolean containsEntity;

    @OneToMany(cascade = CascadeType.ALL, fetch = FetchType.LAZY)
    @JoinColumn(name = "file_change_id", unique = true)
    @Fetch(FetchMode.SUBSELECT)
    private List<LineChange> lineChanges = new ArrayList<>();

    public FileChange() {
    }

    public FileChange(String file) {
        this.file = file;
    }

    public String getFile() {
        return file;
    }

    public boolean getRemoved() {
        return removed;
    }

    public boolean getAdded() {
        return added;
    }

    public List<LineChange> getLineChanges() {
        return lineChanges;
    }

    public void setFile(String file) {
        this.file = file;
    }

    public void setRemoved(boolean removed) {
        this.removed = removed;
    }

    public void setAdded(boolean added) {
        this.added = added;
    }

    public void setLineChanges(List<LineChange> lineChanges) {
        this.lineChanges = lineChanges;
    }

    public boolean isRemoved() {
        return removed;
    }

    public boolean isAdded() {
        return added;
    }

    public Boolean isContainsEntity() {
        return containsEntity;
    }

    public void setContainsEntity(boolean containsEntity) {
        this.containsEntity = containsEntity;
    }
}
