/*
 * Copyright (C) 2021 Anton Romanov - All Rights Reserved
 * You may use, distribute and modify this code, please write to: romanov73@gmail.com.
 */

package ru.ulstu.extractor.service;

import com.sun.istack.NotNull;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.stereotype.Service;
import ru.ulstu.extractor.model.Commit;
import ru.ulstu.extractor.repository.AuthorRepository;
import ru.ulstu.extractor.repository.CommitRepository;
import ru.ulstu.extractor.repository.RepositoryRepository;

import java.util.List;

@Service
public class FilteringService {
    private final AuthorRepository authorRepository;
    private final CommitRepository commitRepository;
    private final RepositoryRepository repositoryRepository;

    public FilteringService(AuthorRepository authorRepository,
                            CommitRepository commitRepository,
                            RepositoryRepository repositoryRepository) {
        this.authorRepository = authorRepository;
        this.commitRepository = commitRepository;
        this.repositoryRepository = repositoryRepository;
    }

    public List<String> getRepositoryAuthors(@NotNull String repositoryUrl,
                                             @NotNull String branchName) {
        return authorRepository.findByRepositoryAndBranch(
                repositoryRepository.findByUrl(repositoryUrl),
                branchName
        );
    }

    public Page<Commit> getCommits(@NotNull String repositoryUrl,
                                   @NotNull String branchName,
                                   String author,
                                   String filter,
                                   Boolean entity,
                                   Pageable pageable) {
        return commitRepository.findByRepositoryAndBranch(
                pageable,
                repositoryRepository.findByUrl(repositoryUrl),
                branchName,
                author,
                filter,
                entity
        );
    }
}
